@@ -1,29 +1,18 @@
-# -*- coding: utf-8 -*-
-"""
-    flask_autoindex
-    ~~~~~~~~~~~~~~~
-
-    The mod_autoindex for `Flask <http://flask.pocoo.org/>`_.
-
-    :copyright: (c) 2010-2013 by Heungsub Lee.
-    :license: BSD, see LICENSE for more details.
-"""
 from __future__ import absolute_import
-from future.builtins import str
-from future.builtins import object
+
 import os
 import re
 
 from flask import *
-from flask.ext.silk import Silk
+from flask_silk import Silk
+from future.builtins import object, str
 from jinja2 import FileSystemLoader, TemplateNotFound
 from werkzeug import cached_property
 
-from .entry import *
 from . import icons
+from .entry import *
 
-
-__version__ = '0.5'
+__version__ = '0.6.3'
 __autoindex__ = '__autoindex__'
 
 
@@ -45,7 +34,7 @@ class AutoIndex(object):
                           is ``True``.
     :param template_context: would be passed to the Jinja2 template when
                              rendering an AutoIndex page.
-    :param silk_options: keyword options for :class:`flask.ext.silk.Silk`.
+    :param silk_options: keyword options for :class:`flask_silk.Silk`.
     """
 
     shared = None
@@ -58,6 +47,7 @@ class AutoIndex(object):
             template_folder = os.path.join(__path__[0], 'templates')
             shared = Blueprint(__autoindex__, __name__,
                                template_folder=template_folder)
+
             @shared.route('/__autoindex__/<path:filename>')
             def static(filename):
                 return send_from_directory(static_folder, filename)
@@ -73,7 +63,7 @@ class AutoIndex(object):
 
     def __init__(self, base, browse_root=None, add_url_rules=True,
                  template_context=None, silk_options=None,
-                 show_hidden=False):
+                 show_hidden=False, sort_by='name', order=1):
         """Initializes an autoindex instance."""
         self.base = base
         if browse_root:
@@ -93,11 +83,11 @@ class AutoIndex(object):
             @self.base.route('/')
             @self.base.route('/<path:path>')
             def autoindex(path='.'):
-                return self.render_autoindex(path)
+                return self.render_autoindex(path, sort_by=sort_by, order=order)
 
     def render_autoindex(self, path, browse_root=None, template=None,
                          template_context=None, endpoint='.autoindex',
-                         show_hidden=None, sort_by='name',
+                         show_hidden=None, sort_by='name', order=1,
                          mimetype=None):
         """Renders an autoindex with the given path.
 
@@ -118,11 +108,24 @@ class AutoIndex(object):
             rootdir = self.rootdir
         path = re.sub(r'\/*$', '', path)
         abspath = os.path.join(rootdir.abspath, path)
+
+        # Disallow to access to an upper path.
+        # This issue was reported by @r4dian.
+        # https://github.com/sublee/flask-autoindex/issues/18
+        relpath = os.path.relpath(abspath, rootdir.abspath)
+        if relpath.startswith(os.path.pardir):
+            return abort(403)
+
         if os.path.isdir(abspath):
             sort_by = request.args.get('sort_by', sort_by)
-            order = {'asc': 1, 'desc': -1}[request.args.get('order', 'asc')]
+            if sort_by[0] in ['-', '+']:
+                order = {'+': 1, '-': -1}[sort_by[0]]
+                sort_by = sort_by[1::]
+            else:
+                order = {'asc': 1, 'desc': -1}[request.args.get('order', 'asc')]
             curdir = Directory(path, rootdir)
-            if show_hidden == None: show_hidden = self.show_hidden
+            if show_hidden == None:
+                show_hidden = self.show_hidden
             entries = curdir.explore(sort_by=sort_by, order=order,
                                      show_hidden=show_hidden)
             if callable(endpoint):
@@ -267,7 +270,7 @@ class AutoIndexModule(AutoIndexBlueprint):
 
     def __init__(self, *args, **kwargs):
         import warnings
-        warnings.warn('AutoIndexModule is deprecated; ' \
+        warnings.warn('AutoIndexModule is deprecated; '
                       'use AutoIndexBlueprint instead.', DeprecationWarning)
         super(AutoIndexModule, self).__init__(*args, **kwargs)
 
